Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(534)

Unified Diff: content/browser/cache_storage/cache_storage_dispatcher_host.h

Issue 1039763002: Cache Storage: Move files to content/*/cache_storage, rename classes (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: GN fix Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/cache_storage/cache_storage_dispatcher_host.h
diff --git a/content/browser/service_worker/cache_storage_dispatcher_host.h b/content/browser/cache_storage/cache_storage_dispatcher_host.h
similarity index 70%
rename from content/browser/service_worker/cache_storage_dispatcher_host.h
rename to content/browser/cache_storage/cache_storage_dispatcher_host.h
index 0c674a760e61d3776ff749dddde8e951c8d0d93e..b922f234f517bc21aee7b72d312ca19b03ee0a53 100644
--- a/content/browser/service_worker/cache_storage_dispatcher_host.h
+++ b/content/browser/cache_storage/cache_storage_dispatcher_host.h
@@ -2,23 +2,23 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_BROWSER_SERVICE_WORKER_CACHE_STORAGE_DISPATCHER_HOST_H_
-#define CONTENT_BROWSER_SERVICE_WORKER_CACHE_STORAGE_DISPATCHER_HOST_H_
+#ifndef CONTENT_BROWSER_CACHE_STORAGE_CACHE_STORAGE_DISPATCHER_HOST_H_
+#define CONTENT_BROWSER_CACHE_STORAGE_CACHE_STORAGE_DISPATCHER_HOST_H_
#include "content/public/browser/browser_message_filter.h"
namespace content {
class CacheStorageContextImpl;
-class ServiceWorkerCacheListener;
+class CacheStorageListener;
// Handles Cache Storage related messages sent to the browser process from
// child processes. One host instance exists per child process. All
// messages are processed on the IO thread. Currently, all messages are
// passed directly to the owned ServiceWorkerCacheListener instance, which
// in turn dispatches calls to the ServiceWorkerCacheStorageManager owned
// by the CacheStorageContextImpl for the entire browsing context.
// TODO(jsbell): Merge this with ServiceWorkerCacheListener crbug.com/439389
class CONTENT_EXPORT CacheStorageDispatcherHost : public BrowserMessageFilter {
public:
CacheStorageDispatcherHost();
@@ -40,11 +40,11 @@ class CONTENT_EXPORT CacheStorageDispatcherHost : public BrowserMessageFilter {
// Called by Init() on IO thread.
void CreateCacheListener(CacheStorageContextImpl* context);
- scoped_ptr<ServiceWorkerCacheListener> cache_listener_;
+ scoped_ptr<CacheStorageListener> cache_listener_;
DISALLOW_COPY_AND_ASSIGN(CacheStorageDispatcherHost);
};
} // namespace content
-#endif // CONTENT_BROWSER_SERVICE_WORKER_CACHE_STORAGE_DISPATCHER_HOST_H_
+#endif // CONTENT_BROWSER_CACHE_STORAGE_CACHE_STORAGE_DISPATCHER_HOST_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,23 +2,23 @@
// child processes. One host instance exists per child process. All
// messages are processed on the IO thread. Currently, all messages are
-// passed directly to the owned ServiceWorkerCacheListener instance, which
-// in turn dispatches calls to the ServiceWorkerCacheStorageManager owned
+// passed directly to the owned CacheStorageListener instance, which
+// in turn dispatches calls to the CacheStorageManager owned
// by the CacheStorageContextImpl for the entire browsing context.
@@ -2,23 +2,23 @@
// by the CacheStorageContextImpl for the entire browsing context.
-// TODO(jsbell): Merge this with ServiceWorkerCacheListener crbug.com/439389
+// TODO(jsbell): Merge this with CacheStorageListener crbug.com/439389
class CONTENT_EXPORT CacheStorageDispatcherHost : public BrowserMessageFilter {
public: